@@ -2,11 +2,9 @@ import textwrap
 
 import pytest
 
-import _pytest.pytester
-
 
 def test_plugin(
-    pytester: _pytest.pytester.Pytester,
+    pytester: pytest.Pytester,
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
     # Initialize variables
@@ -43,19 +41,18 @@ import pathlib
 def test_repo_git_remote_checkout(
     session,
 ) -> None:
-    assert session.name is not None
+    assert session.session_name is not None
 
-    assert session._session_id == "$1"
+    assert session.session_id == "$1"
 
     new_window = session.new_window(attach=False, window_name="my window name")
-    assert new_window.name == "my window name"
+    assert new_window.window_name == "my window name"
         """
         )
     }
-    first_test_key = list(files.keys())[0]
+    first_test_key = next(iter(files.keys()))
     first_test_filename = str(tests_path / first_test_key)
 
-    # Setup: Files
     tests_path.mkdir()
     for file_name, text in files.items():
         test_file = tests_path / file_name
